==> cloud-3.2.0.tar.gz: cloud/src/Form/CloudStoreCopyConfirm.php <==
<?php

namespace Drupal\cloud\Form;

use Drupal\cloud\Entity\CloudContentEntityBase;
use Drupal\Core\Entity\ContentEntityConfirmFormBase;
use Drupal\Core\Entity\EntityRepositoryInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Messenger\Messenger;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Form for copying a cloud store.
 */
class CloudStoreCopyConfirm extends ContentEntityConfirmFormBase {

  /**
   * The Messenger service.
   *
   * @var \Drupal\Core\Messenger\Messenger
   */
  protected $messenger;

  /**
   * {@inheritdoc}
   */
  public function __construct(EntityRepositoryInterface $entity_repository,
                              Messenger $messenger) {
    parent::__construct($entity_repository);
    $this->messenger = $messenger;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity.repository'),
      $container->get('messenger')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getQuestion() {
    $entity = $this->entity;
    return $this->t('Are you sure you want to copy %name?', [
      '%name' => $entity->label(),
    ]);
  }

  /**
   * {@inheritdoc}
   */
  public function getConfirmText() {
    return $this->t('Copy');
  }

  /**
   * {@inheritdoc}
   */
  public function getDescription() {
    return '';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form = parent::buildForm($form, $form_state);
    $form['copy_storage_name'] = [
      '#title' => $this->t('New storage name'),
      '#type' => 'textfield',
      '#description' => $this->t('The new storage name to use.'),
      '#default_value' => $this->t('copy_of_@name',
        [
          '@name' => $this->entity->getName(),
        ]),
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function getCancelUrl() {
    $entity = $this->entity;
    $url = $entity->toUrl('canonical');
    $url->setRouteParameter('cloud_store_type', $entity->bundle());
    return $url;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);
    $entity = $this->entity;

    // Create the new cloud launch template.
    $new_entity = $entity->createDuplicate();
    $new_entity->setName($form_state->getValue('copy_storage_name'));
    $new_entity->validate();
    $new_entity->save();
    $this->messenger->addStatus($this->t('Record copied.'));
    $form_state->setRedirectUrl($new_entity->toUrl('canonical'));

    // Clear block and menu cache.
    CloudContentEntityBase::updateCache();
  }

}

==> cloud-5.1.0.tar.gz: cloud/src/Form/CloudStoreCopyConfirm.php <==
<?php

namespace Drupal\cloud\Form;

use Drupal\cloud\Traits\CloudContentEntityTrait;
use Drupal\Core\Entity\ContentEntityConfirmFormBase;
use Drupal\Core\Entity\EntityRepositoryInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Messenger\Messenger;
use Drupal\Core\Security\TrustedCallbackInterface;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Form for copying a cloud store.
 */
class CloudStoreCopyConfirm extends ContentEntityConfirmFormBase {

  use CloudContentEntityTrait;

  /**
   * The Messenger service.
   *
   * @var \Drupal\Core\Messenger\Messenger
   */
  protected $messenger;

  /**
   * {@inheritdoc}
   */
  public function __construct(EntityRepositoryInterface $entity_repository,
                              Messenger $messenger) {
    parent::__construct($entity_repository);
    $this->messenger = $messenger;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity.repository'),
      $container->get('messenger')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getQuestion(): TranslatableMarkup {
    $entity = $this->entity;
    return $this->t('Are you sure you want to copy %name?', [
      '%name' => $entity->label(),
    ]);
  }

  /**
   * {@inheritdoc}
   */
  public function getConfirmText(): TranslatableMarkup {
    return $this->t('Copy');
  }

  /**
   * {@inheritdoc}
   */
  public function getDescription(): string {
    return '';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $form = parent::buildForm($form, $form_state);
    $form['copy_storage_name'] = [
      '#title' => $this->t('New storage name'),
      '#type' => 'textfield',
      '#description' => $this->t('The new storage name to use.'),
      '#default_value' => $this->t('copy_of_@name',
        [
          '@name' => $this->entity->getName(),
        ]),
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function getCancelUrl(): TrustedCallbackInterface {
    $entity = $this->entity;
    $url = $entity->toUrl('canonical');
    $url->setRouteParameter('cloud_store_type', $entity->bundle());
    return $url;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    parent::submitForm($form, $form_state);
    $entity = $this->entity;

    // Create the new cloud launch template.
    $new_entity = $entity->createDuplicate();
    $new_entity->setName($form_state->getValue('copy_storage_name'));
    $new_entity->validate();
    $new_entity->save();
    $this->messenger->addStatus($this->t('Record copied.'));
    $form_state->setRedirectUrl($new_entity->toUrl('canonical'));

    // Clear block and menu cache.
    $this->clearCacheValues($entity->getCacheTags());
  }

}
